# Generated by Django 2.2.12 on 2020-06-17 10:49

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('security', '0003_migration'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='outputloggedrequest',
            name='celery_task_run_log',
        ),
        migrations.RemoveField(
            model_name='outputloggedrequest',
            name='command_log',
        ),
        migrations.RemoveField(
            model_name='outputloggedrequest',
            name='input_logged_request',
        ),
    ]



# Generated by Django 2.2.12 on 2020-05-31 17:57

from django.db import migrations, models
import enumfields.fields
import security.enums


class Migration(migrations.Migration):
    dependencies = [
        ('security', '0002_migration'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='celerytasklog',
            name='is_set_as_stale',
        ),
        migrations.AddField(
            model_name='celerytasklog',
            name='state',
            field=enumfields.fields.NumEnumField(db_index=True, default=1, enum=security.enums.CeleryTaskLogState,
                                                 verbose_name='state'),
        ),
        migrations.AlterField(
            model_name='celerytasklog',
            name='name',
            field=models.CharField(db_index=True, max_length=250, verbose_name='task name'),
        ),
        migrations.AlterField(
            model_name='celerytaskrunlog',
            name='name',
            field=models.CharField(db_index=True, max_length=250, verbose_name='task name'),
        ),
        migrations.AlterField(
            model_name='celerytaskrunlog',
            name='state',
            field=enumfields.fields.NumEnumField(db_index=True, default=1, enum=security.enums.CeleryTaskRunLogState,
                                                 verbose_name='state'),
        ),
    ]
